diff options
| author | Tatsuhiro Tsujikawa <tatsuhiro.t@gmail.com> | 2007-12-04 11:12:56 +0000 |
|---|---|---|
| committer | Tatsuhiro Tsujikawa <tatsuhiro.t@gmail.com> | 2007-12-04 11:12:56 +0000 |
| commit | 936ce09b8339e2827e949385a0701a6f53a321a9 (patch) | |
| tree | 082014edb685a5ab859a5d4b1a609e7721b5a1c7 /src/ByteArrayDiskWriter.h | |
| parent | d56dddd553f4fa75254f35beb388265573d02ce0 (diff) | |
2007-12-04 Tatsuhiro Tsujikawa <tujikawa at rednoah dot com>
Added XML2SAXMetalinkProcessor class, which is a lot faster than
the predecessor, Xml2MetalinkParser class.
I tested them against 94KB metalink file with 1234 chunk
checksums.
The new one parsed it in 22msec, while it took 6000msec with old
one.
* src/XML2SAXMetalinkProcessor.{h, cc}
* test/XML2SAXMetalinkProcessorTest.cc
* src/MetalinkParserController.{h, cc}
* test/MetalinkParserControllerTest.cc
* src/MetalinkParserState.h: Also added 16 subclasses.
* src/main.cc
* src/Metalink2RequestGroup.cc
* src/MetalinkHelper.cc
* src/MetalinkEntry.cc
* src/ChunkChecksum.h
Rewritten Base64 class for better performance.
* src/Base64.{h, cc}
* test/Base64Test.cc
* src/HttpRequest.cc
Diffstat (limited to 'src/ByteArrayDiskWriter.h')
| -rw-r--r-- | src/ByteArrayDiskWriter.h | 6 |
1 files changed, 6 insertions, 0 deletions
diff --git a/src/ByteArrayDiskWriter.h b/src/ByteArrayDiskWriter.h index 47d99946..f2a646b3 100644 --- a/src/ByteArrayDiskWriter.h +++ b/src/ByteArrayDiskWriter.h @@ -69,6 +69,12 @@ public: virtual void enableDirectIO() {} virtual void disableDirectIO() {} + + void setString(const string& s) + { + buf.str(s); + } }; +typedef SharedHandle<ByteArrayDiskWriter> ByteArrayDiskWriterHandle; #endif // _D_BYTE_ARRAY_DISK_WRITER_H_ |
